import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/views/layout/Layout'

/**
 * 视图组件列表
 * key对应后端数据库lc_rbac_platform中ms_sys_promission表的symbol字段
 */
export const viewComponetList = {
  'app01/ctl01': () => import('@/views/permission/page'),
  'app01/ctl02': () => import('@/views/permission/directive')
}

/** note: submenu only apppear when children.length>=1
 *   detail see  https://panjiachen.github.io/vue-element-admin-site/#/router-and-nav?id=sidebar
 **/

/**
* hidden: true                   if `hidden:true` will not show in the sidebar(default is false)
* alwaysShow: true               if set true, will always show the root menu, whatever its child routes length
*                                if not set alwaysShow, only more than one route under the children
*                                it will becomes nested mode, otherwise not show the root menu
* redirect: noredirect           if `redirect:noredirect` will no redirct in the breadcrumb
* name:'router-name'             the name is used by <keep-alive> (must set!!!)
* meta : {
    roles: ['admin','editor']     will control the page roles (you can set multiple roles)
    title: 'title'               the name show in submenu and breadcrumb (recommend set)
    icon: 'svg-name'             the icon show in the sidebar,
    noCache: true                if true ,the page will no be cached(default is false)
  }
**/
export const constantRouterMap = [
  { path: '/login', component: () => import('@/views/login/index'), hidden: true },
  { path: '/authredirect', component: () => import('@/views/login/authredirect'), hidden: true },
  { path: '/404', component: () => import('@/views/errorPage/404'), hidden: true },
  { path: '/401', component: () => import('@/views/errorPage/401'), hidden: true },
  { path: '', component: Layout, redirect: 'dashboard', hidden: true,
    children: [
      {
        path: 'dashboard',
        component: () => import('@/views/dashboard/index'),
        name: 'dashboard',
        meta: { title: 'dashboard', icon: 'icon-dashboard', noCache: true }
      }
    ]
  }
]

// 通配符匹配404页必须放到最后加载
export const route404 = { path: '*', redirect: '/404', hidden: true, dynamic_router: false }

export default new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRouterMap
})

/**
 * 由前端定义的及菜单，测试阶段用
*/
export const asyncRouterMap = [
  {
    path: '/01',
    component: Layout,
    redirect: 'noredirect',
    name: '01',
    alwaysShow: true,
    meta: {
      title: '菜单01(来至前端)',
      icon: 'lock'
    },
    children: [
      {
        path: '0101',
        component: viewComponetList['app01/ctl01'],
        name: '0101',
        meta: {
          title: '菜单0101'
        }
      },
      {
        path: '0102',
        component: viewComponetList['app01/ctl02'],
        name: '0102',
        meta: {
          title: '菜单0102'
        }
      }
    ]
  }
]
