import { asyncRouterMap, viewComponetList, constantRouterMap, route404 } from '@/router'
import Layout from '@/views/layout/Layout'

/** 将菜单的扁平结构转换为树形结构 */
function menuToTree(menuList) {
  const temp = {}
  const result = []

  // 生成一维菜单数据结构
  for (const i in menuList) {
    const t = menuList[i]
    const _node = (t.pid && t.pid !== '0' && t.pid !== '')
      ? createNode(t)
      : createPNode(t, true)
    temp[_node.id] = _node
  }

  // 一维菜单转树结构
  for (const i in temp) {
    const node = temp[i]
    if (node.pid) {
      const pnode = temp[node.pid]
      if (pnode) {
        if (!pnode.children) {
          pnode.children = []
        }
        pnode.children.push(node)
      }
    } else {
      result.push(node)
    }
  }

  // 对于没子节点的一级菜单，再加上一级父级菜单
  for (const j in result) {
    const t_crtNode = result[j]
    if (!t_crtNode.children || t_crtNode.children.length === 0) {
      var oMenu = menuList.filter(item => { return item.id === t_crtNode.id })[0]
      const t_PNode = createPNode(oMenu, false)
      t_PNode.children = []
      t_PNode.children.push(createNode(oMenu))
      result[j] = t_PNode
    }
  }

  return result
}

/** 创建菜单父结节 */
function createPNode(t, alwaysShow) {
  return {
    id: t.id,
    path: `/${t.symbol}`,
    component: Layout,
    name: t.symbol,
    meta: {
      title: t.display_name,
      icon: t.dic_icon
    },
    redirect: 'noredirect',
    alwaysShow: alwaysShow,
    hidden: false,
    app_ccode: t.app_ccode,
    dic_resource_type: t.dic_resource_type,
    dynamic_router: true
  }
}

/** 创建菜单结点 */
function createNode(t) {
  return {
    id: t.id,
    path: t.symbol,
    component: viewComponetList[t.symbol],
    name: t.symbol,
    meta: {
      title: t.display_name,
      icon: t.dic_icon
    },
    pid: t.pid,
    app_ccode: t.app_ccode,
    dic_resource_type: t.dic_resource_type,
    dynamic_router: true
  }
}

const permission = {
  state: {
    routers: constantRouterMap,
    addRouters: []
  },
  mutations: {
    SET_ROUTERS: (state, routers) => {
      state.addRouters = routers
      state.routers = constantRouterMap.concat(routers)
    }
  },
  actions: {
    GenerateRoutes({ commit }, data) {
      return new Promise(resolve => {
        const { menus } = data
        const _menus = menus.filter(menu => menu.dic_resource_type === 5 && menu.app_ccode === process.env.APP_CCODE) // dic_resource_type等于5为二开菜单资源
        const accessedRouters = !process.env.USE_FROMEND_MENU
          ? menuToTree(_menus) // 服务端定义的菜单
          : asyncRouterMap // 前端定义的菜单
        accessedRouters.push(route404)
        commit('SET_ROUTERS', accessedRouters)
        resolve()
      })
    }
  }
}

export default permission
