/* jshint esversion: 6 */

import { loginByUsername, logout, getCurrentUserInfo } from '@/api/login'
import { getToken, setToken, removeToken, getUserId, setUserId, removeUserId } from '@/utils/auth'
import socket from '@/utils/socket'

const user = {
  state: {
    userId: getUserId(),
    user: '',
    status: '',
    code: '',
    token: getToken(),
    name: '',
    avatar: '',
    introduction: '',
    roles: [],
    setting: {
      articlePlatform: []
    },
    enterprise_ccode: '',
    menus: [],
    apps: [],
    currentRole: {},
    currentRoleApps: []
  },

  mutations: {
    SET_CODE: (state, code) => {
      state.code = code
    },
    SET_TOKEN: (state, token) => {
      state.token = token
    },
    SET_INTRODUCTION: (state, introduction) => {
      state.introduction = introduction
    },
    SET_SETTING: (state, setting) => {
      state.setting = setting
    },
    SET_STATUS: (state, status) => {
      state.status = status
    },
    SET_NAME: (state, name) => {
      state.name = name
    },
    SET_AVATAR: (state, avatar) => {
      state.avatar = avatar
    },
    SET_ROLES: (state, roles) => {
      state.roles = [...roles]
    },
    SET_USER_ID: (state, id) => {
      state.userId = id
    },
    SET_ENTERPRISE_CCODE: (state, ccode) => {
      state.enterprise_ccode = ccode
    },
    SET_MENUS: (state, menus) => {
      state.menus = [...menus]
    },
    SET_APPS: (state, apps) => {
      state.apps = [...apps]
    },
    SET_CURRENTROLE: (state, role) => {
      state.currentRole = role
    },
    SET_CURRENTROLEAPPS: (state, apps) => {
      state.currentRoleApps = apps
    }
  },

  actions: {
    // 用户名登录
    LoginByUsername({ commit }, userInfo) {
      const username = userInfo.username.trim()
      return new Promise((resolve, reject) => {
        loginByUsername(username, userInfo.password)
          .then(response => {
            const resp = response.data
            const data = resp.result
            const token = data.token
            const user = data.user
            commit('SET_TOKEN', token)
            setToken(token)
            commit('SET_USER_ID', user.id)
            setUserId(user.id)
            resolve()
          })
          .catch(error => {
            reject(error)
          })
      })
    },

    // 获取用户信息
    GetUserInfo({ commit, state }) {
      return new Promise((resolve, reject) => {
        getCurrentUserInfo(state.userId)
          .then(response => {
            const resp = response.data
            const data = resp.result
            if (data.roles && data.roles.length > 0) {
              const roleNames = []
              data.roles.forEach(role => {
                roleNames.push(role.role_name)
              })
              commit('SET_CURRENTROLE', data.roles[0])
              data.roles = [...new Set(data.roles)]
              commit('SET_ROLES', data.roles)
              commit('SET_CURRENTROLEAPPS', data.currentRoleApps)
            } else {
              reject('getInfo: 未给当前用户配置角色 !')
            }

            if (data.menus && data.menus.length > 0) {
              const menus = []
              data.menus.forEach(menu => {
                menus.push({
                  display_name: menu.display_name,
                  symbol: menu.symbol
                })
              })
              commit('SET_MENUS', menus)
            }

            if (data.apps && data.apps.length > 0) {
              const apps = []
              data.apps.forEach(app => {
                apps.push({
                  id: app.id,
                  app_name: app.app_name,
                  url: app.url
                })
              })
              commit('SET_APPS', apps)
            }

            const user = data.user
            commit('SET_NAME', user.user_name)
            commit('SET_AVATAR', user.avatar)
            commit('SET_INTRODUCTION', user.remark)
            commit('SET_ENTERPRISE_CCODE', user.enterprise_ccode)
            socket(getToken()) // socket连接服务端

            resolve(data)
          })
          .catch(error => {
            const msg = error.response.data.message || error
            reject(msg)
          })
      })
    },

    // 登出
    LogOut({ commit, state }) {
      return new Promise((resolve, reject) => {
        logout(state.token)
          .then(() => {
            commit('SET_TOKEN', '')
            commit('SET_ROLES', [])
            removeToken()
            removeUserId()
            resolve()
          })
          .catch(error => {
            reject(error)
          })
      })
    },

    // 前端 登出
    FedLogOut({ commit }) {
      return new Promise(resolve => {
        commit('SET_TOKEN', '')
        removeToken()
        removeUserId()
        resolve()
      })
    },

    // 动态修改权限
    ChangeRoles({ commit }, role) {
      return new Promise(resolve => {
        commit('SET_TOKEN', role)
        setToken(role)
        getCurrentUserInfo(role).then(response => {
          const data = response.data
          commit('SET_ROLES', data.roles)
          commit('SET_NAME', data.name)
          commit('SET_AVATAR', data.avatar)
          commit('SET_INTRODUCTION', data.introduction)
          resolve()
        })
      })
    }
  }
}

export default user
