'use strict'
import store from '@/store'

//按钮权限判断
export default function btnPermission(modName) {
  const menus = store.getters.menus  //后台返回的菜单
  const btnConfig = store.getters.btnConfig  //各模块按钮配置
  let permission = {}

  //目标模块按钮（btnConfig[modName]）与menus映射，判断menus中是否包含目标模块按钮
  for (let i in btnConfig[modName]) {
  	//process.env.ENABLED_BTN_PERMISSION 全局是否启用按钮权限过滤配置
  	//是：启用按钮配置，返回目标模块按钮（btnConfig[modName]）与menus映射结果
  	//否：按钮全部启用
    permission[i] = process.env.ENABLED_BTN_PERMISSION ? !!menus.filter(item => item.symbol == btnConfig[modName][i]).length : true
  }

  return permission
}

/**
模块页面应用示例：
<template>
	<el-button :disabled="!pageBtns.create">添加</el-button>
	<el-button :disabled="!pageBtns.update">编辑</el-button>
	<el-button :disabled="!pageBtns.delete">删除</el-button>
</template>
<script>
	import btnPermission from '@/utils/btnPermission'
	export default {
		computed: {
		    //获取按钮权限
		    pageBtns: function() {
		      return btnPermission('模块名')
		    }
		}
	}
</script>
**/