import store from '@/store'
import { MessageBox } from 'element-ui'

export default function socket(userToken) {
  // 判断当前浏览器是否支持WebSocket
  if (!window.websocket && 'WebSocket' in window) {
    window.websocket = new WebSocket(process.env.WEBSOCKET_URL)

    // 连接发生错误的回调方法
    window.websocket.onerror = function() {
      // console.log('webSocket连接失败')
    }

    // 连接成功建立的回调方法
    window.websocket.onopen = function(event) {
      var message = {
        type: 'LOGIN',
        token: userToken,
        data: {}
      }
      window.websocket.send(JSON.stringify(message))
    }

    // 接收到消息的回调方法
    window.websocket.onmessage = function(event) {
      var $data = JSON.parse(event.data)
      switch ($data.type) {
        case 'LOGIN':
          // 登录消息
          if ($data.data.code === 1000) {
            // console.log('登录成功')
          } else {
            // console.log('登录失败')
          }
          break
        case 'MESSAGE':
          // 正常消息推送全在这接收
          // console.log('收到业务消息')
          break
        case 'ERROR':
          // 异常消息
          // console.log('收到异常消息')
          break
        case 'DOWNLINE':
          // console.log('')
          window.websocket.close()
          store.dispatch('FedLogOut').then(() => {
            MessageBox.alert('此帐户已在异地登录，此处将被下线！', '系统提示', {
              confirmButtonText: '确定',
              callback: action => {
                location.reload()
              } })
          }).catch(() => {
            // console.log('退出失败')
          })
          break
      }
    }

    // 监听窗口关闭事件，当窗口关闭时，主动去关闭websocket连接，防止连接还没断开就关闭窗口，server端会抛异常。
    window.onbeforeunload = function() {
      window.websocket.close()
    }
  }
}
